pub struct SqlxTransactionCompanion<C = PostcardCodec>where
C: CacheCodec,{ /* private fields */ }Expand description
SQLx transaction companion.
The companion begins a transaction, gives user code explicit access to the SQLx transaction and an invalidation collector, then either enqueues durable outbox rows before commit or applies local-only invalidation after commit.
Implementations
Sourceimpl<C> SqlxTransactionCompanion<C>where
C: CacheCodec,
impl<C> SqlxTransactionCompanion<C>where
C: CacheCodec,
Sourcepub fn new(queries: DbCache<C>) -> Self
pub fn new(queries: DbCache<C>) -> Self
Create a companion for the given query cache namespace.
Sourcepub fn with_outbox(self, outbox: SqlxInvalidationOutbox) -> Self
pub fn with_outbox(self, outbox: SqlxInvalidationOutbox) -> Self
Attach a durable SQLx invalidation outbox.
Sourcepub fn diagnostics(&self) -> SqlxTransactionDiagnostics
pub fn diagnostics(&self) -> SqlxTransactionDiagnostics
Return transaction companion diagnostics.
Sourcepub async fn sqlite_durable<F, E>(
&self,
pool: &SqlitePool,
reason: impl Into<String>,
body: F,
) -> TransactionResult<SqlxTransactionReport, E>where
F: for<'tx> FnOnce(&'tx mut Transaction<'_, Sqlite>, &'tx mut InvalidationCollector) -> SqlxTransactionFuture<'tx, E> + Send,
E: Error + Send + Sync + 'static,
pub async fn sqlite_durable<F, E>(
&self,
pool: &SqlitePool,
reason: impl Into<String>,
body: F,
) -> TransactionResult<SqlxTransactionReport, E>where
F: for<'tx> FnOnce(&'tx mut Transaction<'_, Sqlite>, &'tx mut InvalidationCollector) -> SqlxTransactionFuture<'tx, E> + Send,
E: Error + Send + Sync + 'static,
Execute a SQLite transaction and enqueue invalidation intent before commit.
Sourcepub async fn sqlite_local<F, E>(
&self,
pool: &SqlitePool,
reason: impl Into<String>,
body: F,
) -> TransactionResult<SqlxTransactionReport, E>where
F: for<'tx> FnOnce(&'tx mut Transaction<'_, Sqlite>, &'tx mut InvalidationCollector) -> SqlxTransactionFuture<'tx, E> + Send,
E: Error + Send + Sync + 'static,
pub async fn sqlite_local<F, E>(
&self,
pool: &SqlitePool,
reason: impl Into<String>,
body: F,
) -> TransactionResult<SqlxTransactionReport, E>where
F: for<'tx> FnOnce(&'tx mut Transaction<'_, Sqlite>, &'tx mut InvalidationCollector) -> SqlxTransactionFuture<'tx, E> + Send,
E: Error + Send + Sync + 'static,
Execute a SQLite transaction and apply invalidation directly after commit.
This mode is intentionally non-durable. It is useful for local demos and
single-process tests, while production writes should use
SqlxTransactionCompanion::sqlite_durable.